@@ -5,4 +5,4 @@
 
 # This script runs LOLA from a Linux shell
 
-java -jar lola-1.2-beta.jar 
+java -Xmx512M -jar lola-1.3-beta.jar 
